/**
 * Copyright 2020 Colin Doig.  Distributed under the MIT license.
 */
import JsonMember from '../JsonMember';
import OrderStatus from '../sport/enum/OrderStatus';
import OrderType from '../sport/enum/OrderType';
import PersistenceType from '../sport/enum/PersistenceType';
import Side from '../sport/enum/Side';
export interface IOrderOptions {
    betId: string;
    orderType: OrderType | string;
    status: OrderStatus | string;
    persistenceType: PersistenceType | string;
    side: Side | string;
    price: number;
    size: number;
    bspLiability: number;
    placedDate: Date | string;
    avgPriceMatched?: number;
    sizeMatched?: number;
    sizeRemaining?: number;
    sizeLapsed?: number;
    sizeCancelled?: number;
    sizeVoided?: number;
    customerOrderRef?: string;
    customerStrategyRef?: string;
}
export default class Order extends JsonMember {
    private betId;
    private orderType;
    private status;
    private persistenceType;
    private side;
    private price;
    private size;
    private bspLiability;
    private placedDate;
    private avgPriceMatched?;
    private sizeMatched?;
    private sizeRemaining?;
    private sizeLapsed?;
    private sizeCancelled?;
    private sizeVoided?;
    private customerOrderRef?;
    private customerStrategyRef?;
    constructor(options: IOrderOptions);
    toJson(): IOrderOptions;
    getBetId(): string;
    setBetId(betId: string): void;
    getOrderType(): OrderType;
    setOrderType(orderType: OrderType): void;
    getStatus(): OrderStatus;
    setStatus(status: OrderStatus): void;
    getPersistenceType(): PersistenceType;
    setPersistenceType(persistenceType: PersistenceType): void;
    getSide(): Side;
    setSide(side: Side): void;
    getPrice(): number;
    setPrice(price: number): void;
    getSize(): number;
    setSize(size: number): void;
    getBspLiability(): number;
    setBspLiability(bspLiability: number): void;
    getPlacedDate(): Date;
    setPlacedDate(placedDate: Date): void;
    getAvgPriceMatched(): number | undefined;
    setAvgPriceMatched(avgPriceMatched: number): void;
    getSizeMatched(): number | undefined;
    setSizeMatched(sizeMatched: number): void;
    getSizeRemaining(): number | undefined;
    setSizeRemaining(sizeRemaining: number): void;
    getSizeLapsed(): number | undefined;
    setSizeLapsed(sizeLapsed: number): void;
    getSizeCancelled(): number | undefined;
    setSizeCancelled(sizeCancelled: number): void;
    getSizeVoided(): number | undefined;
    setSizeVoided(sizeVoided: number): void;
    getCustomerOrderRef(): string | undefined;
    setCustomerOrderRef(customerOrderRef: string): void;
    getCustomerStrategyRef(): string | undefined;
    setCustomerStrategyRef(customerStrategyRef: string): void;
}
